# KM3NeT data files

## IRFs
The IRFs for KM3NeT can be found in /irfs stored as fits files. The files follow the 'GADF' format [details](https://gamma-astro-data-formats.readthedocs.io/en/v0.3/)

### Generation of the KM3NeT IRFs

The KM3NeT IRFs are based on extensive simulations of neutrinos and anti-neutrinos that interact in or nearby the detector. We focus on charged-current interactions of muon neutrinos only which provide a good angular resolution. The simulated events have beed reweighted to a power-law spectrum with index −2.5, which is representative of typical Galactic γ-ray sources. This only affects the distribution of the events within each energy bin. For the given energy binning this has a very minor effect on the resuling IRFs.

Two types of background events are relevant for the KM3NeT analysis: neutrinos and muons, both created in CR-induced atmospheric air showers. To predict the rate of atmospheric neutrino events, we use the ‘HKKMS’ model for conventional neutrinos and the ‘ERS’ model for prompt neutrinos.

The background of atmospheric muons has been estimated using dedicated simulations of muons using the MUPAGE package. 
All simulated events are reconstructed using a track reconstruction algorithm and subsequently undergo a selection procedure based on the reconstruction quality and a classification algorithm using boosted decision trees (BDTs). In order to suppress the background of atmospheric muons, which always arrive from above the detector, we restrict the analysis region to zenith angles θ > 80◦. Thus, only very few atmospheric muon events remain in the final sample, almost all concentrated close to the horizon region (80◦ < θ < 90◦). This also means that the IRFs provided here are **only valid for zenith angles > 80 deg**.

The KM3NeT IRFs mainly depend on neutrino energy and zenith angle. To be able to store the IRFs in the (IACT-centred) GADF data format, we utilise the offset angle axis defined there to describe the dependence of the KM3NeT IRFs on the zenith angle. The IRFs are then generated by creating histograms of the appropriate event properties (e.g. the angle between the reconstructed and true neutrino direction in case of the PSF) and applying corresponding normalisation factors. For the effective area IRF, we use 48 log-arithmic bins in true energy between 100 GeV and 100 PeV and 12 zenith angle bins linear in cos(θ). The energy dispersion and PSF IRFs – featuring one more dimensions than the effective area – are created with twice the bin size, in order to ensure sufficient statistics in each bin. IRFs for neutrinos and anti-neutrinos are derived separately and subsequently averaged, assuming equipartition of the source flux between the two.

## Pseudodata sets

### Using the original data set
The pseudodata sets are generated using _Create_KM3NeT_datasets_ notebook. As the observation time of KM3NeT assumed here is 10 years, the data generation is binned for 1 year of observation and then multiplied. As the binning of the scan for the original pseudodata sets is 1 hour intervals, the execution of the script for one source takes about 1 day on a standard CPU. You can download the full pseudodata set for all sources in the original binning from the KM3NeT Open Data Center: http://opendata.km3net.de/storage/KM3NeT_pseudodata_10y_CTAKM3NeTcombined_2023.tar.gz (3.1GB), writing into the `/pseudodata` folder. It is worth noting that the paths in the respective `.yml` files must be adjusted according to the location of the loaded datasets.

From this folder, execute
```sh
wget http://opendata.km3net.de/storage/KM3NeT_pseudodata_10y_CTAKM3NeTcombined_2023.tar.gz
tar -xvzf KM3NeT_pseudodata_10y_CTAKM3NeTcombined_2023.tar.gz

```
In order to use this dataset, set the property io - km3net_pseudodata_extension to "__10y" in `Analysis/analyis_config.yml` to use this dataset. If you change the default data folder location, be aware that you might have to adjust the data paths in the `KM3NeT_{SOURCE}_10y_models.yml` and `KM3NeT_{SOURCE}_10y_datasets.yml` files.

### Generating your own datasets

In order to test pseudodata set generation, you can run the notebook with a larger binning by configuring Analysis/analysis_config.yml, setting the property km3net_datasets - hours. Choosing a larger binning than in the original case (hours = 1) will reduce the generation time of the datasets. Chose a different folder name extension by setting io - km3net_pseudodata_extension to a meaningful string.

## Plots

Plots generated by _Plot_KM3NeT_datasets_ are stored in this folder.